In gpu reset, XGMI TA unload will cause gpu hang.
Skip it on A+A aldebaran.

Signed-off-by: Feifei Xu <feifei...@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c 
b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
index 80a4dc51951e..bae304b0d67a 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
@@ -791,8 +791,9 @@ static int psp_xgmi_unload(struct psp_context *psp)
        struct psp_gfx_cmd_resp *cmd;
        struct amdgpu_device *adev = psp->adev;
 
-       /* XGMI TA unload currently is not supported on Arcturus */
-       if (adev->asic_type == CHIP_ARCTURUS)
+       /* XGMI TA unload currently is not supported on Arcturus/Aldebaran A+A 
*/
+       if (adev->asic_type == CHIP_ARCTURUS ||
+               (adev->asic_type == CHIP_ALDEBARAN && 
adev->gmc.xgmi.connected_to_cpu))
                return 0;
 
        /*
-- 
2.25.1

_______________________________________________
amd-gfx mailing list
amd-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/amd-gfx

Reply via email to